@@ -1,12 +1,12 @@
 import unittest
 
-from scss.parser import Stylecheet
+from scss.parser import Stylesheet
 
 
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylecheet()
+        self.parser = Stylesheet()
 
     def test_variables(self):
         src = """
@@ -18,6 +18,9 @@ class TestSCSS( unittest.TestCase ):
                     li {
                         color: red;
                     }
+                    &:hover {
+                        width: 20px;
+                    }
                 }
             }
 
@@ -29,7 +32,7 @@ class TestSCSS( unittest.TestCase ):
                 }
             }
             """
-        test = "table.hl {\n\tmargin: 2em 0}\n\ntable.hl td.ln {\n\ttext-align: right}\n\ntable.hl td.ln li {\n\tcolor: red}\n\nli {\n\tfont-weight: bold;\n\tfont-size: 1.2em;\n\tfont-family: serif}"
-        out = self.parser.parse(src)
+        test = "table.hl {\n\tmargin: 2em 0}\n\ntable.hl td.ln {\n\ttext-align: right}\n\ntable.hl td.ln li {\n\tcolor: #f00}\n\ntable.hl td.ln:hover {\n\twidth: 20px}\n\nli {\n\tfont-weight: bold;\n\tfont-size: 1.2em;\n\tfont-family: serif}\n\n"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
