@@ -6,21 +6,7 @@ from scss.parser import Stylesheet
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylesheet(options=dict(compress=True))
-
-    def test_bugs(self):
-        src = """
-            .bug {
-                background: -webkit-gradient(linear, top left, 100% 100%, from(#ddd), to(#aaa));
-            }
-
-            .bug-moz {
-                background: -moz-linear-gradient (top, #DDD, #AAA);
-            }
-        """
-        test = ".bug{background:-webkit-gradient(linear, top left, 100% 100%, from(#ddd), to(#aaa))}.bug-moz{background:-moz-linear-gradient(top, #ddd, #aaa)}"
-        out = self.parser.loads(src)
-        self.assertEqual(test, out)
+        self.parser = Stylesheet()
 
     def test_base(self):
         src = """
@@ -62,7 +48,7 @@ class TestSCSS( unittest.TestCase ):
                 border:2px; }
 
             """
-        test = "@charset utf-8;\n@import url(test);\n@media print { a:hover, a:active{outline:none}a, a:active, a:visited{color:#607890}a:hover{color:#036} }body:not(.test){margin-bottom:.5em;font-family:Georgia , sans-serif;*font:13px / 1.231 sans-serif}::selection{color:#f00}.test:hover{color:#f00}.test:hover:after{content:#00f}pre, code, kbd, samp{font:12px / 10px;font-family:monospace , sans-serif}abbr[title], dfn[title]{border:2px}"
+        test = "@charset utf-8;\n@import url(test);\n@media print { a:hover, a:active {\n\toutline: none}\n\na, a:active, a:visited {\n\tcolor: #607890}\n\na:hover {\n\tcolor: #036}\n\n }/* Css comment */\nbody:not(.test) {\n\tmargin-bottom: .5em;\n\tfont-family: Georgia , sans-serif;\n\t*font: 13px / 1.231 sans-serif}\n\n::selection {\n\tcolor: #f00}\n\n.test:hover {\n\tcolor: #f00}\n\n.test:hover:after {\n\tcontent: #00f}\n\npre, code, kbd, samp {\n\tfont: 12px / 10px;\n\tfont-family: monospace , sans-serif}\n\nabbr[title], dfn[title] {\n\tborder: 2px}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -74,7 +60,7 @@ class TestSCSS( unittest.TestCase ):
           li { float: left;
             a .test .main{ font-weight: bold; }
           } }"""
-        test = "#navbar{width:80%;height:23px}#navbar ul{list-style-type:none}#navbar li{float:left}#navbar li a .test .main{font-weight:bold}"
+        test = "#navbar {\n\twidth: 80%;\n\theight: 23px}\n\n#navbar ul {\n\tlist-style-type: none}\n\n#navbar li {\n\tfloat: left}\n\n#navbar li a .test .main {\n\tfont-weight: bold}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -85,7 +71,7 @@ class TestSCSS( unittest.TestCase ):
                 left: { width: 4px; color: #888; }
                 right: { width: 2px; color: #ccc; }
             } }"""
-        test = ".fakeshadow{border-style:solid;border-right-width:2px;border-right-color:#ccc;border-left-width:4px;border-left-color:#888}"
+        test = ".fakeshadow {\n\tborder-style: solid;\n\tborder-right-width: 2px;\n\tborder-right-color: #ccc;\n\tborder-left-width: 4px;\n\tborder-left-color: #888}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -94,7 +80,7 @@ class TestSCSS( unittest.TestCase ):
             &:hover { color: #ffb3ff; }
             &:visited { color: #c458cb; }
             .test & { color: red; }}"""
-        test = "a{color:#ce4dd6}a:hover{color:#ffb3ff}a:visited{color:#c458cb}.test a{color:#f00}"
+        test = "a {\n\tcolor: #ce4dd6}\n\na:hover {\n\tcolor: #ffb3ff}\n\na:visited {\n\tcolor: #c458cb}\n\n.test a {\n\tcolor: #f00}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -106,7 +92,7 @@ class TestSCSS( unittest.TestCase ):
             $def_test: beep-beep !default;
             #navbar { border-bottom: { color: $main-color; style: $style; } }
             a.#{$def_test} { color: $main-color; &:hover { border-bottom: $style 1px; } }"""
-        test = "#navbar{border-bottom-style:solid;border-bottom-color:#ce4dd6}a.second{color:#ce4dd6}a.second:hover{border-bottom:solid 1px}"
+        test = "#navbar {\n\tborder-bottom-style: solid;\n\tborder-bottom-color: #ce4dd6}\n\na.second {\n\tcolor: #ce4dd6}\n\na.second:hover {\n\tborder-bottom: solid 1px}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -117,7 +103,7 @@ class TestSCSS( unittest.TestCase ):
             border-#{$side}-radius: $radius;
             -moz-border-radius-#{$side}: $radius;
             -webkit-border-#{$side}-radius: $radius; }"""
-        test = "div.rounded-top p{border-top-radius:10px;-moz-border-radius-top:10px;-webkit-border-top-radius:10px}"
+        test = "div.rounded-top p {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -129,7 +115,7 @@ class TestSCSS( unittest.TestCase ):
             #navbar li { @include rounded(top); }
             #footer { @include rounded(top, 5px); }
             #sidebar { @include rounded(left, 8px); }"""
-        test = "#navbar li{border-top-radius:10px;-moz-border-radius-top:10px;-webkit-border-top-radius:10px}#footer{border-top-radius:5px;-moz-border-radius-top:5px;-webkit-border-top-radius:5px}#sidebar{border-left-radius:8px;-moz-border-radius-left:8px;-webkit-border-left-radius:8px}"
+        test = "#navbar li {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}\n\n#footer {\n\tborder-top-radius: 5px;\n\t-moz-border-radius-top: 5px;\n\t-webkit-border-top-radius: 5px}\n\n#sidebar {\n\tborder-left-radius: 8px;\n\t-moz-border-radius-left: 8px;\n\t-webkit-border-left-radius: 8px}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
 
@@ -141,6 +127,6 @@ class TestSCSS( unittest.TestCase ):
             .error .intrusion { background-image: url(/image/hacked.png); }
             .seriousError { @extend .error; border-width: 3px; }
             """
-        test = ".error, .seriousError{border:1px #f00;background-color:#fdd}a:hover{text-decoration:underline}.error .intrusion, .seriousError .intrusion{background-image:url(/image/hacked.png)}.seriousError{border-width:3px}"
+        test = ".error, .seriousError {\n\tborder: 1px #f00;\n\tbackground-color: #fdd}\n\na:hover {\n\ttext-decoration: underline}\n\n.error .intrusion, .seriousError .intrusion {\n\tbackground-image: url(/image/hacked.png)}\n\n.seriousError {\n\tborder-width: 3px}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
